Module pool

Module pool 

A pool of ids that can be used to reuse ids in Dynamic.

Structs

Flag
A Pool that can hold one scalar element of type ()
Sequence
A Pool that iterates over it’s elements and tries to put a given OpaqueScalar into one of it’s sub-pools. May fail if it can’t put an element into any of it’s pools
SyncQueuePoolstd
A thread safe queue-pool, it returns scalars in FIFO order
SyncStackPoolstd
A thread safe stack-pool, it returns scalars in LIFO order

Traits

Pool
A pool of ids that can be used to reuse ids in Dynamic.
PoolMut
A pool of ids that can be used to reuse ids in Dynamic.