OneShotIdentifier

Trait OneShotIdentifier 

pub unsafe trait OneShotIdentifier: Identifier { }
An Identifier who’s tokens are guaranteed to never be owned by another Identifier, even if this one is dropped

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<I: ?Sized + OneShotIdentifier> OneShotIdentifier for Box<I>

Available on crate feature alloc only.

Implementors